@@ -16,7 +16,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
  * Boston, MA  02111-1307  USA.
  *
- * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gnome2/gnome2perl.h,v 1.3 2003/05/22 16:10:09 muppetman Exp $
+ * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gnome2/gnome2perl.h,v 1.4 2003/07/11 05:02:14 muppetman Exp $
  */
 
 #ifndef _GNOME2PERL_H_
@@ -28,4 +28,10 @@
 #include <libgnome/libgnometypebuiltins.h>
 #include "gnome2perl-autogen.h"
 
+/*
+ * custom typemap handling for GnomeUIInfo, defined in GnomeAppHelper.xs
+ */
+GnomeUIInfo * SvGnomeUIInfo (SV * sv);
+
+
 #endif /* _GNOME2PERL_H_ */
